virlsdk package — virlsdk 0.1.post0.dev1+ng910c7a3.dirty documentation

# virlsdk package

## Submodules

## virlsdk.launch_sim module

`virlsdk.launch_sim.` `main`()

## virlsdk.stop_sim module

`virlsdk.stop_sim.` `main`()

## virlsdk.virlsdk module

Bunch of functions to abstract the VIRL STD APIs

class `virlsdk.virlsdk.` `Virl`(virl, username, password)

  Bases: `object`

  `getintf`(simname)
  `getnode`(simname)
  `getsims`()
  `getstatus`(simname)
  `startsim`(payload)
  `stopsim`(simname)

## Module contents